@@ -8,6 +8,7 @@ namespace Sass {
     extern const char image_path_var[] = "$[image path]";
 
     // sass keywords
+    extern const char at_root_kwd[]       = "@at-root";
     extern const char import_kwd[]        = "@import";
     extern const char mixin_kwd[]         = "@mixin";
     extern const char function_kwd[]      = "@function";
@@ -26,10 +27,16 @@ namespace Sass {
     extern const char in_kwd[]            = "in";
     extern const char while_kwd[]         = "@while";
     extern const char warn_kwd[]          = "@warn";
+    extern const char error_kwd[]         = "@error";
+    extern const char debug_kwd[]         = "@debug";
     extern const char default_kwd[]       = "default";
     extern const char global_kwd[]        = "global";
     extern const char null_kwd[]          = "null";
     extern const char optional_kwd[]      = "optional";
+    extern const char with_kwd[]          = "with";
+    extern const char without_kwd[]       = "without";
+    extern const char all_kwd[]           = "all";
+    extern const char rule_kwd[]          = "rule";
 
     // css standard units
     extern const char em_kwd[]   = "em";
@@ -42,6 +49,7 @@ namespace Sass {
     extern const char deg_kwd[]  = "deg";
     extern const char rad_kwd[]  = "rad";
     extern const char grad_kwd[] = "grad";
+    extern const char turn_kwd[] = "turn";
     extern const char ms_kwd[]   = "ms";
     extern const char s_kwd[]    = "s";
     extern const char Hz_kwd[]   = "Hz";
