@@ -1,4 +1,5 @@
-#define SASS_CONSTANTS
+#ifndef SASS_CONSTANTS_H
+#define SASS_CONSTANTS_H
 
 namespace Sass {
   namespace Constants {
@@ -8,6 +9,7 @@ namespace Sass {
     extern const char image_path_var[];
 
     // sass keywords
+    extern const char at_root_kwd[];
     extern const char import_kwd[];
     extern const char mixin_kwd[];
     extern const char function_kwd[];
@@ -26,10 +28,16 @@ namespace Sass {
     extern const char in_kwd[];
     extern const char while_kwd[];
     extern const char warn_kwd[];
+    extern const char error_kwd[];
+    extern const char debug_kwd[];
     extern const char default_kwd[];
     extern const char global_kwd[];
     extern const char null_kwd[];
     extern const char optional_kwd[];
+    extern const char with_kwd[];
+    extern const char without_kwd[];
+    extern const char all_kwd[];
+    extern const char rule_kwd[];
 
     // css standard units
     extern const char em_kwd[];
@@ -42,6 +50,7 @@ namespace Sass {
     extern const char deg_kwd[];
     extern const char rad_kwd[];
     extern const char grad_kwd[];
+    extern const char turn_kwd[];
     extern const char ms_kwd[];
     extern const char s_kwd[];
     extern const char Hz_kwd[];
@@ -140,3 +149,5 @@ namespace Sass {
 
   }
 }
+
+#endif
\ No newline at end of file
