@@ -1,21 +1,14 @@
-#define SASS_FUNCTIONS
-
-#ifndef SASS_ENVIRONMENT
-#include "environment.hpp"
-#endif
-
-#ifndef SASS
-#include "sass.h"
-#endif
+#ifndef SASS_FUNCTIONS_H
+#define SASS_FUNCTIONS_H
 
 #include <string>
 
-#ifndef SASS_POSITION
 #include "position.hpp"
-#endif
+#include "environment.hpp"
+#include "sass_functions.h"
 
 #define BUILT_IN(name) Expression*\
-name(Env& env, Env& d_env, Context& ctx, Signature sig, const string& path, Position position, Backtrace* backtrace)
+name(Env& env, Env& d_env, Context& ctx, Signature sig, ParserState pstate, Backtrace* backtrace)
 
 namespace Sass {
   struct Context;
@@ -25,7 +18,7 @@ namespace Sass {
   class Definition;
   typedef Environment<AST_Node*> Env;
   typedef const char* Signature;
-  typedef Expression* (*Native_Function)(Env&, Env&, Context&, Signature, const string&, Position, Backtrace*);
+  typedef Expression* (*Native_Function)(Env&, Env&, Context&, Signature, ParserState, Backtrace*);
 
   Definition* make_native_function(Signature, Native_Function, Context&);
   Definition* make_c_function(Signature sig, Sass_C_Function f, void* cookie, Context& ctx);
@@ -77,6 +70,8 @@ namespace Sass {
     extern Signature abs_sig;
     extern Signature min_sig;
     extern Signature max_sig;
+    extern Signature inspect_sig;
+    extern Signature random_sig;
     extern Signature length_sig;
     extern Signature nth_sig;
     extern Signature index_sig;
@@ -93,6 +88,7 @@ namespace Sass {
     extern Signature global_variable_exists_sig;
     extern Signature function_exists_sig;
     extern Signature mixin_exists_sig;
+    extern Signature feature_exists_sig;
     extern Signature call_sig;
     extern Signature not_sig;
     extern Signature if_sig;
@@ -105,6 +101,7 @@ namespace Sass {
     extern Signature map_has_key_sig;
     extern Signature keywords_sig;
     extern Signature set_nth_sig;
+    extern Signature unique_id_sig;
 
     BUILT_IN(rgb);
     BUILT_IN(rgba_4);
@@ -148,6 +145,8 @@ namespace Sass {
     BUILT_IN(abs);
     BUILT_IN(min);
     BUILT_IN(max);
+    BUILT_IN(inspect);
+    BUILT_IN(random);
     BUILT_IN(length);
     BUILT_IN(nth);
     BUILT_IN(index);
@@ -164,6 +163,7 @@ namespace Sass {
     BUILT_IN(global_variable_exists);
     BUILT_IN(function_exists);
     BUILT_IN(mixin_exists);
+    BUILT_IN(feature_exists);
     BUILT_IN(call);
     BUILT_IN(sass_not);
     BUILT_IN(sass_if);
@@ -176,6 +176,9 @@ namespace Sass {
     BUILT_IN(map_has_key);
     BUILT_IN(keywords);
     BUILT_IN(set_nth);
+    BUILT_IN(unique_id);
 
   }
 }
+
+#endif
