@@ -1,6 +1,7 @@
 #include "inspect.hpp"
 #include "ast.hpp"
 #include "context.hpp"
+#include "utf8/checked.h"
 #include <cmath>
 #include <string>
 #include <iostream>
@@ -9,7 +10,13 @@
 namespace Sass {
   using namespace std;
 
-  Inspect::Inspect(Context* ctx) : buffer(""), indentation(0), ctx(ctx) { }
+  Inspect::Inspect(Context* ctx)
+  : buffer(""),
+    indentation(0),
+    ctx(ctx),
+    in_declaration(false),
+    in_declaration_list(false)
+  { }
   Inspect::~Inspect() { }
 
   // statements
@@ -48,6 +55,12 @@ namespace Sass {
     ruleset->block()->perform(this);
   }
 
+  void Inspect::operator()(Keyframe_Rule* rule)
+  {
+    if (rule->rules()) rule->rules()->perform(this);
+    rule->block()->perform(this);
+  }
+
   void Inspect::operator()(Propset* propset)
   {
     propset->property_fragment()->perform(this);
@@ -101,6 +114,7 @@ namespace Sass {
   void Inspect::operator()(Declaration* dec)
   {
     if (dec->value()->concrete_type() == Expression::NULL_VAL) return;
+    in_declaration = true;
     if (ctx) ctx->source_map.add_open_mapping(dec->property());
     source_map.add_open_mapping(dec->property());
     dec->property()->perform(this);
@@ -114,6 +128,7 @@ namespace Sass {
     if (ctx) ctx->source_map.add_close_mapping(dec->value());
     source_map.add_close_mapping(dec->value());
     append_to_buffer(";");
+    in_declaration = false;
   }
 
   void Inspect::operator()(Assignment* assn)
@@ -285,6 +300,7 @@ namespace Sass {
     string sep(list->separator() == List::SPACE ? " " : ", ");
     if (list->empty()) return;
     bool items_output = false;
+    in_declaration_list = in_declaration;
     for (size_t i = 0, L = list->length(); i < L; ++i) {
       Expression* list_item = (*list)[i];
       if (list_item->is_invisible()) {
@@ -294,6 +310,7 @@ namespace Sass {
       list_item->perform(this);
       items_output = true;
     }
+    in_declaration_list = false;
   }
 
   void Inspect::operator()(Binary_Expression* expr)
@@ -389,7 +406,7 @@ namespace Sass {
     ) {
       error(d + n->unit() + " isn't a valid CSS value.", n->pstate());
     }
-    if (!n->zero()) {
+    if (!n->zero() && !in_declaration_list) {
       if (d.substr(0, 3) == "-0.") d.erase(1, 1);
       if (d.substr(0, 2) == "0.") d.erase(0, 1);
     }
@@ -752,17 +769,60 @@ namespace Sass {
     if (s.length() == 1) {
       if (s[0] == '"' || s[0] == '\'') return "";
     }
-    char q;
-    if      (*s.begin() == '"'  && *s.rbegin() == '"')  q = '"';
-    else if (*s.begin() == '\'' && *s.rbegin() == '\'') q = '\'';
+    // char q;
+    if      (*s.begin() == '"'  && *s.rbegin() == '"')  {} // q = '"';
+    else if (*s.begin() == '\'' && *s.rbegin() == '\'') {} // q = '\'';
     else                                                return s;
     string t;
     t.reserve(s.length()-2);
+
     for (size_t i = 1, L = s.length()-1; i < L; ++i) {
-      // if we see a quote, we need to remove the preceding backslash from t
-      if (s[i-1] == '\\' && s[i] == q) t.erase(t.length()-1);
-      t.push_back(s[i]);
+
+      // implement the same strange ruby sass behavior
+      // an escape sequence can also mean a unicode char
+      if (s[i] == '\\') {
+
+        // skip it
+        ++ i;
+
+        // escape length
+        size_t len = 0;
+
+        // parse as many sequence chars as possible
+        // ToDo: Check if ruby aborts after possible max
+        while (s[i + len] && isxdigit(s[i + len])) ++ len;
+
+        // hex string?
+        if (len == 0) {
+
+          // add next char
+          t.push_back(s[i]);
+
+        } else {
+
+          // convert the extracted hex string to code point value
+          // ToDo: Maybe we could do this without creating a substring
+          uint32_t cp = strtol(s.substr (i, len).c_str(), nullptr, 16);
+
+          // use a very simple approach to convert via utf8 lib
+          // maybe there is a more elegant way; maybe we shoud
+          // convert the whole output from string to a stream!?
+          // allocate memory for utf8 char and convert to utf8
+          unsigned char u[5] = {0,0,0,0,0}; utf8::append(cp, u);
+          for(size_t m = 0; u[m] && m < 5; m++) t.push_back(u[m]);
+
+          // skip some more chars?
+          if (len > 1) i += len - 1;
+
+        }
+        // EO if hex
+
+      } else {
+        // add single char
+        t.push_back(s[i]);
+      }
     }
+
     return t;
   }
 
