@@ -1,30 +1,16 @@
-#define SASS_PARSER
+#ifndef SASS_PARSER_H
+#define SASS_PARSER_H
 
-#include <vector>
 #include <map>
-
-#ifndef SASS_PRELEXER
-#include "prelexer.hpp"
-#endif
-
-#ifndef SASS_TOKEN
-#include "token.hpp"
-#endif
-
-#ifndef SASS_CONTEXT
-#include "context.hpp"
-#endif
-
-#ifndef SASS_AST
-#include "ast.hpp"
-#endif
-
-#ifndef SASS_POSITION
-#include "position.hpp"
-#endif
-
+#include <vector>
 #include <iostream>
 
+#include "ast.hpp"
+#include "token.hpp"
+#include "context.hpp"
+#include "position.hpp"
+#include "prelexer.hpp"
+
 struct Selector_Lookahead {
   const char* found;
   bool has_interpolants;
@@ -36,7 +22,9 @@ namespace Sass {
   using std::map;
   using namespace Prelexer;
 
-  class Parser {
+  class Parser : public ParserState {
+  private:
+    void add_single_file (Import* imp, string import_path);
   public:
     class AST_Node;
 
@@ -47,21 +35,23 @@ namespace Sass {
     const char* source;
     const char* position;
     const char* end;
-    string path;
-    size_t column;
-    Position source_position;
+    Position before_token;
+    Position after_token;
+    ParserState pstate;
 
 
     Token lexed;
+    bool dequote;
+    bool in_at_root;
 
-    Parser(Context& ctx, string path, Position source_position)
-    : ctx(ctx), stack(vector<Syntactic_Context>()),
-      source(0), position(0), end(0), path(path), column(1), source_position(source_position)
-    { stack.push_back(nothing); }
+    Parser(Context& ctx, ParserState pstate)
+    : ParserState(pstate), ctx(ctx), stack(vector<Syntactic_Context>()),
+      source(0), position(0), end(0), before_token(pstate), after_token(pstate), pstate("[NULL]")
+    { dequote = false; in_at_root = false; stack.push_back(nothing); }
 
-    static Parser from_string(string src, Context& ctx, string path = "", Position source_position = Position());
-    static Parser from_c_str(const char* src, Context& ctx, string path = "", Position source_position = Position());
-    static Parser from_token(Token t, Context& ctx, string path = "", Position source_position = Position());
+    static Parser from_string(string src, Context& ctx, ParserState pstate = ParserState("[STRING]"));
+    static Parser from_c_str(const char* src, Context& ctx, ParserState pstate = ParserState("[CSTRING]"));
+    static Parser from_token(Token t, Context& ctx, ParserState pstate = ParserState("[TOKEN]"));
 
 #ifdef __clang__
 
@@ -79,98 +69,124 @@ namespace Sass {
     const char* peek(const char* start = 0)
     {
       if (!start) start = position;
-      const char* after_whitespace;
+      const char* it_before_token;
       if (mx == block_comment) {
-        after_whitespace = // start;
+        it_before_token = // start;
           zero_plus< alternatives<spaces, line_comment> >(start);
       }
       else if (/*mx == ancestor_of ||*/ mx == no_spaces) {
-        after_whitespace = position;
+        it_before_token = position;
       }
       else if (mx == spaces || mx == ancestor_of) {
-        after_whitespace = mx(start);
-        if (after_whitespace) {
-          return after_whitespace;
+        it_before_token = mx(start);
+        if (it_before_token) {
+          return it_before_token;
         }
         else {
           return 0;
         }
       }
       else if (mx == optional_spaces) {
-        after_whitespace = optional_spaces(start);
+        it_before_token = optional_spaces(start);
       }
       else if (mx == line_comment_prefix || mx == block_comment_prefix) {
-        after_whitespace = position;
+        it_before_token = position;
       }
       else {
-        after_whitespace = spaces_and_comments(start);
+        it_before_token = spaces_and_comments(start);
       }
-      const char* after_token = mx(after_whitespace);
-      if (after_token) {
-        return after_token;
+      const char* it_after_token = mx(it_before_token);
+      if (it_after_token) {
+        return it_after_token;
       }
       else {
         return 0;
       }
     }
 
+    // white-space handling is built into the lexer
+    // this way you do not need to parse it yourself
+    // some matchers don't accept certain white-space
     template <prelexer mx>
     const char* lex()
     {
-      const char* after_whitespace;
+
+      // advance position for next call
+      before_token = after_token;
+
+      // after optional whitespace
+      const char* it_before_token;
+
       if (mx == block_comment) {
-        after_whitespace = // position;
-          zero_plus< alternatives<spaces, line_comment> >(position);
+        // a block comment can be preceded by spaces and/or line comments
+        it_before_token = zero_plus< alternatives<spaces, line_comment> >(position);
       }
-      else if (mx == url) {
-        after_whitespace = position;
-      }
-      else if (mx == ancestor_of || mx == no_spaces) {
-        after_whitespace = position;
+      else if (mx == url || mx == ancestor_of || mx == no_spaces) {
+        // parse everything literally
+        it_before_token = position;
       }
+
       else if (mx == spaces) {
-        after_whitespace = spaces(position);
-        if (after_whitespace) {
-          source_position.line += count_interval<'\n'>(position, after_whitespace);
-          lexed = Token(position, after_whitespace);
-          return position = after_whitespace;
+        it_before_token = spaces(position);
+        if (it_before_token) {
+          return position = it_before_token;
         }
         else {
           return 0;
         }
       }
+
       else if (mx == optional_spaces) {
-        after_whitespace = optional_spaces(position);
+        // ToDo: what are optiona_spaces ???
+        it_before_token = optional_spaces(position);
       }
       else {
-        after_whitespace = spaces_and_comments(position);
+        // most can be preceded by spaces and comments
+        it_before_token = spaces_and_comments(position);
       }
-      const char* after_token = mx(after_whitespace);
-      if (after_token) {
-        size_t previous_line = source_position.line;
-        source_position.line += count_interval<'\n'>(position, after_token);
 
-        size_t whitespace = 0;
-        const char* ptr = after_whitespace - 1;
-        while (ptr >= position) {
-          if (*ptr == '\n')
-            break;
-          whitespace++;
-          ptr--;
+      // now call matcher to get position after token
+      const char* it_after_token = mx(it_before_token);
+      // assertion that we got a valid match
+      if (it_after_token == 0) return 0;
+
+      // add whitespace after previous and before this token
+      while (position < it_before_token && *position) {
+        if (*position == '\n') {
+          ++ before_token.line;
+          before_token.column = 0;
+        } else {
+          ++ before_token.column;
         }
-        if (previous_line != source_position.line) {
-          column = 1;
+        ++position;
+      }
+
+      // copy position
+      after_token = before_token;
+
+      Offset size(0, 0);
+
+      // increase position to include current token
+      while (position < it_after_token && *position) {
+        if (*position == '\n') {
+          ++ size.line;
+          size.column = 0;
+        } else {
+          ++ size.column;
         }
-
-        source_position.column = column + whitespace;
-        column += after_token - after_whitespace + whitespace;
-        lexed = Token(after_whitespace, after_token);
-
-        return position = after_token;
-      }
-      else {
-        return 0;
+        ++position;
       }
+
+      after_token = after_token + size;
+
+      // create parsed token string (public member)
+      lexed = Token(it_before_token, it_after_token, before_token);
+
+      pstate = ParserState(path, Position(before_token.file, before_token.line, before_token.column), size);
+
+      // advance internal char iterator
+      return position = it_after_token;
+
     }
 
 #ifdef __clang__
@@ -179,7 +195,7 @@ namespace Sass {
 
 #endif
 
-    void error(string msg, Position pos = Position());
+    void error(string msg, Position pos);
     void read_bom();
 
     Block* parse();
@@ -220,7 +236,9 @@ namespace Sass {
     Function_Call_Schema* parse_function_call_schema();
     String* parse_interpolated_chunk(Token);
     String* parse_string();
-    String* parse_ie_stuff();
+    String_Constant* parse_static_value();
+    String* parse_ie_property();
+    String* parse_ie_keyword_arg();
     String_Schema* parse_value_schema();
     String* parse_identifier_schema();
     String_Schema* parse_url_schema();
@@ -233,14 +251,19 @@ namespace Sass {
     Media_Query* parse_media_query();
     Media_Query_Expression* parse_media_expression();
     Feature_Block* parse_feature_block();
-    Feature_Queries* parse_feature_queries();
-    Feature_Query* parse_feature_query();
+    Feature_Query* parse_feature_queries();
+    Feature_Query_Condition* parse_feature_query();
+    Feature_Query_Condition* parse_feature_query_in_parens();
     Feature_Query_Condition* parse_supports_negation();
     Feature_Query_Condition* parse_supports_conjunction();
     Feature_Query_Condition* parse_supports_disjunction();
-    Feature_Query_Condition* parse_supports_declaration_condition();
+    Feature_Query_Condition* parse_supports_declaration();
+    At_Root_Block* parse_at_root_block();
+    At_Root_Expression* parse_at_root_expression();
     At_Rule* parse_at_rule();
     Warning* parse_warning();
+    Error* parse_error();
+    Debug* parse_debug();
 
     Selector_Lookahead lookahead_for_selector(const char* start = 0);
     Selector_Lookahead lookahead_for_extension_target(const char* start = 0);
@@ -254,3 +277,5 @@ namespace Sass {
 
   size_t check_bom_chars(const char* src, const char *end, const unsigned char* bom, size_t len);
 }
+
+#endif
