@@ -1,20 +1,11 @@
-#define SASS_SOURCE_MAP
+#ifndef SASS_SOURCE_MAP_H
+#define SASS_SOURCE_MAP_H
 
 #include <vector>
 
-#ifndef SASS_MAPPING
-#include "mapping.hpp"
-#endif
-
-#ifndef SASS_AST
-#include "ast.hpp"
-#endif
-
-#ifndef SASSS_BASE64VLQ
+#include "ast_fwd_decl.hpp"
 #include "base64vlq.hpp"
-#endif
-
-
+#include "mapping.hpp"
 
 namespace Sass {
   using std::vector;
@@ -25,13 +16,16 @@ namespace Sass {
 
   public:
     vector<size_t> source_index;
+    SourceMap();
     SourceMap(const string& file);
 
     void remove_line();
     void update_column(const string& str);
-    void add_mapping(AST_Node* node);
+    void add_open_mapping(AST_Node* node);
+    void add_close_mapping(AST_Node* node);
 
     string generate_source_map(Context &ctx);
+    ParserState remap(const ParserState& pstate);
 
   private:
 
@@ -44,3 +38,5 @@ namespace Sass {
   };
 
 }
+
+#endif
